echo off
SETLOCAL

if "%1" == "" (
    echo.
    echo usage: build collection-name buildtype
    echo.
    echo collection-name  the name of the collection to build [e.g. demo]
    echo                  collection-name is not optional
    echo buildtype        optional argument - import is the default
    echo                  running with build option set to build
    echo                  [i.e. build demo build] means collection will be 
    echo                  built directly from existing archives bypassing 
    echo                  the import step.
    echo.
    goto END
)

REM set some environment variables
if %GSDLHOME% == "" (
    set GSDLHOME=c:\gsdl
    echo build.bat WARNING: GSDLHOME was not set - setting to %GSDLHOME%
)
set GSDLOS=windows
set PATH=%PATH%;%GSDLHOME%\bin\script;%GSDLHOME%\bin\%GSDLOS%

REM if there are archives but no import stuff we want to build
REM directly from the archives
if EXIST %GSDLHOME%\collect\%1\archives\archives.inf (
    if NOT EXIST %GSDLHOME%\collect\%1\import\* (
	echo.
        echo build.bat: archives exist but import data does not
        echo            building directly from archives
        echo.
        goto BUILD
    ) else goto CHECKIMPORT
) else (
    if EXIST %GSDLHOME%\collect\%1\archives\* (
        rmdir /Q /S %GSDLHOME%\collect\%1\archives
    )
    goto IMPORT
)

:CHECKIMPORT
if %2 == build (
    echo.
    echo build.bat: building directly from existing archives
    echo.
    goto BUILD
) else (
    echo.
    echo build.bat: deleting existing archives before re-importing
    echo.
    rmdir /Q /S %GSDLHOME%\collect\%1\archives
)

:IMPORT
echo build.bat: importing %1 collection
echo.

REM do the import
perl %GSDLHOME%\bin\script\import.pl %1

REM check that import was successful
if NOT EXIST %GSDLHOME%\collect\%1\archives\archives.inf (
    echo "import.pl failed"
    goto END
)

REM do the build
:BUILD
perl %GSDLHOME%\bin\script\buildcol.pl %1

REM check that build was successful
if NOT EXIST %GSDLHOME%\collect\%1\building\text\%1.ldb (
    echo "buildcol.pl failed"
    goto END
)

REM remove old indexes
if EXIST %GSDLHOME%\collect\%1\index (
    rmdir /Q /S %GSDLHOME%\collect\%1\index
)

REM move built indexes into live index directory
rename %GSDLHOME%\collect\%1\building index

echo %1 collection built successfully
echo.

:END
ENDLOCAL
echo on
